@@ -8,8 +8,6 @@
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from __future__ import absolute_import, division, print_function
-
 import collections
 import os
 import os.path
@@ -17,9 +15,19 @@ import subprocess
 import sys
 import ast
 import tokenize
+import warnings
 
 import dateutil.parser
 
+if sys.version_info.major != 3:
+    sys.exit("scikit-bio can only be used with Python 3. You are currently "
+             "running Python %d." % sys.version_info.major)
+
+
+class ChecklistWarning(Warning):
+    """General warning class for warnings raised by checklist.py."""
+    pass
+
 
 def main():
     """Go on a power trip by nitpicking the scikit-bio repo.
@@ -39,7 +47,7 @@ def main():
     root = 'skbio'
     validators = [InitValidator(), CopyrightHeadersValidator(),
                   ExecPermissionValidator(), GeneratedCythonValidator(),
-                  APIRegressionValidator(), FluxCapacitorValidator()]
+                  APIRegressionValidator()]
 
     return_code = 0
     for validator in validators:
@@ -53,7 +61,7 @@ def main():
     return return_code
 
 
-class RepoValidator(object):
+class RepoValidator:
     """Abstract base class representing a repository validator.
 
     Subclasses must override and implement ``_validate`` (see its docstring for
@@ -152,6 +160,12 @@ class CopyrightHeadersValidator(RepoValidator):
     See the current standard for scikit-bio's copyright headers at
     ``http://scikit-bio.org/docs/latest/development/new_module.html``
 
+    Individual files are ignored if the first line in the file is exactly:
+
+    # checklist.py:CopyrightHeadersValidator IGNORE
+
+    If a file is ignored, a ``ChecklistWarning`` is raised.
+
     Parameters
     ----------
     skip_dirs : iterable of str, optional
@@ -188,8 +202,20 @@ class CopyrightHeadersValidator(RepoValidator):
         for _file in files:
             if not _file.endswith('.py'):
                 continue
+
             pos = 0
-            f = open(os.path.join(root, _file))
+            filepath = os.path.join(root, _file)
+            f = open(filepath)
+
+            first_line = f.readline().rstrip('\n')
+            if first_line == '# checklist.py:CopyrightHeadersValidator IGNORE':
+                warnings.warn(
+                    "File %s has IGNORE directive. Ignoring scikit-bio "
+                    "copyright header validation." % filepath,
+                    ChecklistWarning)
+                continue
+
+            f.seek(0)
             tokens = list(tokenize.generate_tokens(f.readline))
 
             # A module docstring is fully described using just two tokens: the
@@ -450,32 +476,5 @@ class APIRegressionValidator(RepoValidator):
         return skbio_imports
 
 
-class FluxCapacitorValidator(RepoValidator):
-    """Ensure that the __future__ statements are fluxing correctly"""
-    reason = ("These files do not have the following import at the start:\n\n"
-              "from __future__ import absolute_import, division,"
-              " print_function\n")
-
-    def _validate(self, root, dirs, files):
-        failures = []
-        expected = {"absolute_import", "division", "print_function"}
-        for file in files:
-            if file.endswith(".py"):
-                filename = os.path.join(root, file)
-                failures.append(filename)
-                with open(filename) as f:
-                    source = ast.parse(f.read())
-                    for node, _ in zip(ast.iter_child_nodes(source), range(2)):
-                        if isinstance(node, ast.Expr):
-                            continue
-                        if isinstance(node, ast.ImportFrom):
-                            if node.module == "__future__":
-                                if expected.issubset(
-                                        {n.name for n in node.names}):
-                                    failures.pop()
-                            break
-        return failures
-
-
 if __name__ == '__main__':
     sys.exit(main())
