@@ -6,8 +6,6 @@
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from __future__ import absolute_import, division, print_function
-
 import numpy as np
 
 from skbio.diversity._util import _validate_counts_vector
@@ -213,7 +211,7 @@ def _get_interval_for_r_new_otus(seq, r):
 
         # bail out if not enough unseen
         if not count or (unseen < r):
-            raise StopIteration
+            return
 
         # make a copy of seen before yielding, as we'll continue to add to the
         # set in subsequent iterations
