@@ -281,31 +281,41 @@ class BetaDiversityTests(TestCase):
                        [0, 0, 25, 35, 0, 19, 0]]
         self.sids2 = list('ABCDEF')
 
+    def test_qualitative_bug_issue_1549(self):
+        mat = np.array([[42, 0, 37, 99, 1],
+                        [12, 1, 22, 88, 0],
+                        [25, 3, 23, 86, 0],
+                        [0, 0, 87, 12, 0]])
+        as_presence_absence = mat > 0
+        obs_mat = beta_diversity('jaccard', mat)
+        obs_presence_absence = beta_diversity('jaccard', as_presence_absence)
+        self.assertEqual(obs_mat, obs_presence_absence)
+
     def test_invalid_input(self):
         # number of ids doesn't match the number of samples
-        error_msg = ("Number of rows")
+        error_msg = (r"Number of rows")
         with self.assertRaisesRegex(ValueError, error_msg):
             beta_diversity(self.table1, list('AB'), 'euclidean')
 
         # unknown metric provided
-        error_msg = "not-a-metric"
+        error_msg = r"not-a-metric"
         with self.assertRaisesRegex(ValueError, error_msg):
             beta_diversity('not-a-metric', self.table1)
 
         # 3-D list provided as input
-        error_msg = ("Only 1-D and 2-D")
+        error_msg = (r"Only 1-D and 2-D")
         with self.assertRaisesRegex(ValueError, error_msg):
             beta_diversity('euclidean', [[[43]]])
 
         # negative counts
-        error_msg = "negative values."
+        error_msg = r"negative values."
         with self.assertRaisesRegex(ValueError, error_msg):
             beta_diversity('euclidean', [[0, 1, 3, 4], [0, 3, -12, 42]])
         with self.assertRaisesRegex(ValueError, error_msg):
             beta_diversity('euclidean', [[0, 1, 3, -4], [0, 3, 12, 42]])
 
         # additional kwargs
-        error_msg = ("'not_a_real_kwarg'")
+        error_msg = r"keyword argument"
         with self.assertRaisesRegex(TypeError, error_msg):
             beta_diversity('euclidean', [[0, 1, 3], [0, 3, 12]],
                            not_a_real_kwarg=42.0)
@@ -714,7 +724,7 @@ class TestPartialBetaDiversity(TestCase):
                                         expected_dm[id1, id2], 6)
 
     def test_self_self_pair(self):
-        error_msg = ("A duplicate or a self-self pair was observed.")
+        error_msg = (r"A duplicate or a self-self pair was observed.")
         with self.assertRaisesRegex(ValueError, error_msg):
             partial_beta_diversity((lambda x, y: x + y), self.table1,
                                    self.sids1, id_pairs=[('A', 'B'),
@@ -723,7 +733,7 @@ class TestPartialBetaDiversity(TestCase):
     def test_duplicate_pairs(self):
         # confirm that partial pairwise execution fails if duplicate pairs are
         # observed
-        error_msg = ("A duplicate or a self-self pair was observed.")
+        error_msg = (r"A duplicate or a self-self pair was observed.")
         with self.assertRaisesRegex(ValueError, error_msg):
             partial_beta_diversity((lambda x, y: x + y), self.table1,
                                    self.sids1, id_pairs=[('A', 'B'),
@@ -732,7 +742,7 @@ class TestPartialBetaDiversity(TestCase):
     def test_duplicate_transpose_pairs(self):
         # confirm that partial pairwise execution fails if a transpose
         # duplicate is observed
-        error_msg = ("A duplicate or a self-self pair was observed.")
+        error_msg = (r"A duplicate or a self-self pair was observed.")
         with self.assertRaisesRegex(ValueError, error_msg):
             partial_beta_diversity((lambda x, y: x + y), self.table1,
                                    self.sids1, id_pairs=[('A', 'B'),
@@ -740,7 +750,7 @@ class TestPartialBetaDiversity(TestCase):
 
     def test_pairs_not_subset(self):
         # confirm raise when pairs are not a subset of IDs
-        error_msg = ("`id_pairs` are not a subset of `ids`")
+        error_msg = (r"`id_pairs` are not a subset of `ids`")
         with self.assertRaisesRegex(ValueError, error_msg):
             partial_beta_diversity((lambda x, y: x + y), self.table1,
                                    self.sids1, id_pairs=[('x', 'b'), ])
@@ -771,7 +781,7 @@ class TestPartialBetaDiversity(TestCase):
 
     def test_unusable_metric(self):
         id_pairs = [('A', 'B'), ('B', 'F'), ('D', 'E')]
-        error_msg = "partial_beta_diversity is only compatible"
+        error_msg = r"partial_beta_diversity is only compatible"
         with self.assertRaisesRegex(ValueError, error_msg):
             partial_beta_diversity('hamming', self.table2, self.sids2,
                                    id_pairs=id_pairs)
