@@ -27,6 +27,16 @@ class GenBankFormatError(FileFormatError):
     pass
 
 
+class EMBLFormatError(FileFormatError):
+    """Raised when a ``EMBL`` formatted file cannot be parsed."""
+    pass
+
+
+class GFF3FormatError(FileFormatError):
+    """Raised when a ``GFF3`` formatted file cannot be parsed."""
+    pass
+
+
 class BLAST7FormatError(FileFormatError):
     """Raised when a ``blast7`` formatted file cannot be parsed."""
     pass
