@@ -8,7 +8,7 @@ Classes
 -------
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    IORegistry
    Format
@@ -17,7 +17,7 @@ Functions
 ---------
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    create_format
 
@@ -25,7 +25,7 @@ Exceptions
 ----------
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    DuplicateRegistrationError
    InvalidRegistrationError
@@ -167,8 +167,6 @@ The following are not yet used but should be avoided as well:
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from __future__ import absolute_import, division, print_function
-
 from warnings import warn
 import types
 import traceback
@@ -176,8 +174,6 @@ import itertools
 import inspect
 from functools import wraps
 
-from future.builtins import zip
-
 from ._exception import DuplicateRegistrationError, InvalidRegistrationError
 from . import (UnrecognizedFormatError, ArgumentOverrideWarning,
                FormatIdentificationWarning)
@@ -188,7 +184,7 @@ from skbio.util._decorator import stable, classonlymethod
 FileSentinel = make_sentinel("FileSentinel")
 
 
-class IORegistry(object):
+class IORegistry:
     """Create a registry of formats and implementations which map to classes.
 
     """
@@ -371,7 +367,8 @@ class IORegistry(object):
         file : openable (filepath, URL, filehandle, etc.)
             The file to sniff. Something that is understood by `skbio.io.open`.
         kwargs : dict, optional
-            Keyword arguments will be passed to `skbio.io.open`.
+            Keyword arguments will be passed to `skbio.io.open`. `newline`
+            cannot be provided.
 
         Returns
         -------
@@ -385,8 +382,14 @@ class IORegistry(object):
             This occurs when the format is not 'claimed' by any registered
             sniffer or when the format is ambiguous and has been 'claimed' by
             more than one sniffer.
+        TypeError
+            If `newline` is provided in `kwargs`.
 
         """
+        if 'newline' in kwargs:
+            raise TypeError(
+                "Cannot provide `newline` keyword argument when sniffing.")
+
         # By resolving the input here, we have the oppurtunity to reuse the
         # file (which is potentially ephemeral). Each sniffer will also resolve
         # the file, but that call will short-circuit and won't claim
@@ -457,7 +460,8 @@ class IORegistry(object):
             When True, will double check the `format` if provided.
         kwargs : dict, optional
             Keyword arguments will be passed to their respective handlers
-            (`skbio.io.open` and the reader for `format`)
+            (`skbio.io.open` and the reader for `format`). `newline` cannot be
+            provided.
 
         Returns
         -------
@@ -468,6 +472,8 @@ class IORegistry(object):
         ------
         ValueError
             Raised when `format` and `into` are both None.
+        TypeError
+            If `newline` is provided in `kwargs`.
         UnrecognizedFormatError
             Raised when a reader could not be found for a given `format` or the
             format could not be guessed.
@@ -479,6 +485,10 @@ class IORegistry(object):
             overriding the suggestion provided by the sniffer of `format`.
 
         """
+        if 'newline' in kwargs:
+            raise TypeError(
+                "Cannot provide `newline` keyword argument when reading.")
+
         # Context managers do not compose well with generators. We have to
         # duplicate the logic so that the file will stay open while yielding.
         # Otherwise the context exits as soon as the generator is returned
@@ -492,7 +502,13 @@ class IORegistry(object):
             # on the first call from __iter__
             # eta-reduction is possible, but we want to the type to be
             # GeneratorType
-            return (x for x in itertools.chain([next(gen)], gen))
+            try:
+                return (x for x in itertools.chain([next(gen)], gen))
+            except StopIteration:
+                # If the error was a StopIteration, then we want to return an
+                # empty generator as `next(gen)` failed.
+                # See #1313 for more info.
+                return (x for x in [])
         else:
             return self._read_ret(file, format, into, verify, kwargs)
 
@@ -512,9 +528,7 @@ class IORegistry(object):
         with _resolve_file(file, **io_kwargs) as (file, _, _):
             reader, kwargs = self._init_reader(file, fmt, into, verify, kwargs,
                                                io_kwargs)
-            generator = reader(file, **kwargs)
-            while True:
-                yield next(generator)
+            yield from reader(file, **kwargs)
 
     def _find_io_kwargs(self, kwargs):
         return {k: kwargs[k] for k in _open_kwargs if k in kwargs}
@@ -544,11 +558,25 @@ class IORegistry(object):
 
         reader = self.get_reader(fmt, into)
         if reader is None:
+            possible_intos = [r.__name__ for r in
+                              self._get_possible_readers(fmt)]
+            message = ''
+            if possible_intos:
+                message = ("Possible values for `into` include: %s"
+                           % ', '.join(possible_intos))
+            into_message = '`into` also not provided.' if not into else ''
             raise UnrecognizedFormatError(
-                "Cannot read %r from %r, no %s reader found." %
-                (fmt, file, into.__name__ if into else 'generator'))
+                "Cannot read %r from %r, no %s reader found. %s %s" %
+                (fmt, file, into.__name__ if into else 'generator',
+                 into_message, message))
         return reader, kwargs
 
+    def _get_possible_readers(self, fmt):
+        for lookup in self._lookups:
+            if fmt in lookup:
+                return list(lookup[fmt].readers)
+        return []
+
     @stable(as_of="0.4.0")
     def write(self, obj, format, into, **kwargs):
         """Write `obj` as `format` into a file.
@@ -741,7 +769,7 @@ skbio.io.util.open
 """
 
 
-class Format(object):
+class Format:
     """Defines a format on which readers/writers/sniffer can be registered.
 
     Parameters
@@ -779,7 +807,7 @@ class Format(object):
     @property
     @stable(as_of="0.4.0")
     def readers(self):
-        """Dictionary that maps classes to their writers for this format."""
+        """Dictionary that maps classes to their readers for this format."""
         return self._readers
 
     @property
@@ -937,7 +965,7 @@ class Format(object):
         >>> registry.add_format(myformat)
         >>> # If developing a new format for skbio, use the create_format()
         >>> # factory instead of the above.
-        >>> class MyObject(object):
+        >>> class MyObject:
         ...     def __init__(self, content):
         ...         self.content = content
         ...
@@ -977,9 +1005,7 @@ class Format(object):
                         file_params, file, encoding, newline, kwargs)
                     with open_files(files, mode='r', **io_kwargs) as fhs:
                         kwargs.update(zip(file_keys, fhs[:-1]))
-                        generator = reader_function(fhs[-1], **kwargs)
-                        while True:
-                            yield next(generator)
+                        yield from reader_function(fhs[-1], **kwargs)
 
             self._add_reader(cls, wrapped_reader, monkey_patch, override)
             return wrapped_reader
@@ -1024,7 +1050,7 @@ class Format(object):
         >>> registry.add_format(myformat)
         >>> # If developing a new format for skbio, use the create_format()
         >>> # factory instead of the above.
-        >>> class MyObject(object):
+        >>> class MyObject:
         ...     default_write_format = 'myformat'
         ...     def __init__(self, content):
         ...         self.content = content
