@@ -24,10 +24,6 @@ Classes
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from skbio.util import TestRunner
-
 from ._interval import Interval, IntervalMetadata
 
 __all__ = ['Interval', 'IntervalMetadata']
-
-test = TestRunner(__file__).test
