@@ -304,8 +304,6 @@ Class-level methods contain information about the molecule types.
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from skbio.util import TestRunner
-
 from ._sequence import Sequence
 from ._protein import Protein
 from ._dna import DNA
@@ -315,5 +313,3 @@ from ._grammared_sequence import GrammaredSequence
 
 __all__ = ['Sequence', 'Protein', 'DNA', 'RNA', 'GeneticCode',
            'GrammaredSequence']
-
-test = TestRunner(__file__).test
