@@ -19,10 +19,6 @@ class NucleotideMixin(metaclass=ABCMeta):
 
     This is an abstract base class (ABC) that cannot be instantiated.
 
-    Attributes
-    ----------
-    complement_map
-
     See Also
     --------
     DNA
@@ -222,7 +218,7 @@ class NucleotideMixin(metaclass=ABCMeta):
 
     @stable(as_of='0.4.0')
     def is_reverse_complement(self, other):
-        """Determine if a sequence is the reverse complement of this sequence.
+        r"""Determine if a sequence is the reverse complement of this sequence.
 
         Parameters
         ----------
