@@ -15,7 +15,7 @@ from ._grammared_sequence import GrammaredSequence, DisableSubclassingMeta
 
 class RNA(GrammaredSequence, NucleotideMixin,
           metaclass=DisableSubclassingMeta):
-    """Store RNA sequence data and optional associated metadata.
+    r"""Store RNA sequence data and optional associated metadata.
 
     Only characters in the IUPAC RNA character set [1]_ are supported.
 
@@ -50,20 +50,6 @@ class RNA(GrammaredSequence, NucleotideMixin,
         certain that the sequence characters are valid. To store sequence data
         that is not IUPAC-compliant, use ``Sequence``.
 
-    Attributes
-    ----------
-    values
-    metadata
-    interval_metadata
-    positional_metadata
-    alphabet
-    gap_chars
-    default_gap_char
-    definite_chars
-    degenerate_chars
-    degenerate_map
-    complement_map
-
     See Also
     --------
     DNA
