@@ -45,7 +45,7 @@ class TestDNA(unittest.TestCase):
         self.assertEqual(seq, DNA('ATAT'))
 
     def test_cannot_subclass(self):
-        with self.assertRaisesRegex(TypeError, "Subclassing disabled"):
+        with self.assertRaisesRegex(TypeError, r"Subclassing disabled"):
             class CustomSequence(DNA):
                 pass
 
