@@ -26,8 +26,8 @@ class TestNucleotideSequence(unittest.TestCase):
     def setUp(self):
         self.sequence_kinds = frozenset([
             str,
-            lambda s: np.fromstring(s, dtype='|S1'),
-            lambda s: np.fromstring(s, dtype=np.uint8)])
+            lambda s: np.frombuffer(s.encode('ascii'), dtype='|S1'),
+            lambda s: np.frombuffer(s.encode('ascii'), dtype=np.uint8)])
 
         dna_str = 'ACGTMRWSYKVHDBN.-'
         dna_comp_str = 'TGCAKYWSRMBDHVN.-'
@@ -174,7 +174,7 @@ class TestNucleotideSequence(unittest.TestCase):
 
     def test_translate_invalid_id(self):
         for seq in RNA('AUG'), DNA('ATG'):
-            with self.assertRaisesRegex(ValueError, 'table_id.*42'):
+            with self.assertRaisesRegex(ValueError, r'table_id.*42'):
                 seq.translate(42)
 
     def test_translate_six_frames_ncbi_table_id(self):
@@ -229,7 +229,7 @@ class TestNucleotideSequence(unittest.TestCase):
 
     def test_translate_six_frames_invalid_id(self):
         for seq in RNA('AUG'), DNA('ATG'):
-            with self.assertRaisesRegex(ValueError, 'table_id.*42'):
+            with self.assertRaisesRegex(ValueError, r'table_id.*42'):
                 seq.translate_six_frames(42)
 
     def test_repr(self):
@@ -326,11 +326,11 @@ class TestNucleotideSequence(unittest.TestCase):
             rc = constructor(seq_str).complement(reverse=True)
             self.assertEqual(rc, constructor(rev_comp_str))
 
-            l = len(seq_str)
-            im = IntervalMetadata(l)
+            length = len(seq_str)
+            im = IntervalMetadata(length)
             im.add([(0, 1)], metadata={'gene': 'p53'})
-            im_rc = IntervalMetadata(l)
-            im_rc.add([(l-1, l)], metadata={'gene': 'p53'})
+            im_rc = IntervalMetadata(length)
+            im_rc.add([(length-1, length)], metadata={'gene': 'p53'})
             original = constructor(
                 seq_str,
                 metadata={'id': 'foo', 'description': 'bar'},
@@ -456,7 +456,7 @@ class TestNucleotideSequence(unittest.TestCase):
             seq2 = DifferentSequenceClass('ABC')
 
             with self.assertRaisesRegex(TypeError,
-                                        "Cannot use.*and "
+                                        r"Cannot use.*and "
                                         "DifferentSequenceClass together"):
                 seq1.is_reverse_complement(seq2)
 
