@@ -40,7 +40,7 @@ Classes
 ^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    DissimilarityMatrix
    DistanceMatrix
@@ -49,7 +49,7 @@ Functions
 ^^^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    randdm
 
@@ -57,7 +57,7 @@ Exceptions
 ^^^^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    DissimilarityMatrixError
    DistanceMatrixError
@@ -150,16 +150,17 @@ Categorical Variable Stats
 ^^^^^^^^^^^^^^^^^^^^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    anosim
    permanova
+   permdisp
 
 Continuous Variable Stats
 ^^^^^^^^^^^^^^^^^^^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    bioenv
 
@@ -167,7 +168,7 @@ Distance Matrix Comparisons
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    mantel
    pwmantel
@@ -187,8 +188,6 @@ References
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from skbio.util import TestRunner
-
 from ._base import (DissimilarityMatrixError, DistanceMatrixError,
                     MissingIDError, DissimilarityMatrix, DistanceMatrix,
                     randdm)
@@ -196,9 +195,8 @@ from ._bioenv import bioenv
 from ._anosim import anosim
 from ._permanova import permanova
 from ._mantel import mantel, pwmantel
+from ._permdisp import permdisp
 
 __all__ = ['DissimilarityMatrixError', 'DistanceMatrixError', 'MissingIDError',
            'DissimilarityMatrix', 'DistanceMatrix', 'randdm', 'anosim',
-           'permanova', 'bioenv', 'mantel', 'pwmantel']
-
-test = TestRunner(__file__).test
+           'permanova', 'bioenv', 'mantel', 'pwmantel', 'permdisp']
