@@ -59,7 +59,7 @@ class MantelTests(MantelTestData):
     def setUp(self):
         super(MantelTests, self).setUp()
 
-        self.methods = ('pearson', 'spearman')
+        self.methods = ('pearson', 'spearman', 'kendalltau')
         self.alternatives = ('two-sided', 'greater', 'less')
 
         # No variation in distances. Taken from Figure 10.20(b), pg. 603 in L&L
@@ -91,7 +91,8 @@ class MantelTests(MantelTestData):
         for n in (0, 99, 999):
             for alt in self.alternatives:
                 for method, exp in (('pearson', self.exp_x_vs_y),
-                                    ('spearman', 0.5)):
+                                    ('spearman', 0.5),
+                                    ('kendalltau', 0.33333333333333337)):
                     obs = mantel(self.minx, self.miny, method=method,
                                  permutations=n, alternative=alt)[0]
                     self.assertAlmostEqual(obs, exp)
@@ -112,7 +113,8 @@ class MantelTests(MantelTestData):
     def test_zero_permutations(self):
         for alt in self.alternatives:
             for method, exp in (('pearson', self.exp_x_vs_y),
-                                ('spearman', 0.5)):
+                                ('spearman', 0.5),
+                                ('kendalltau', 0.33333333333333337)):
                 obs = mantel(self.minx, self.miny, permutations=0,
                              method=method, alternative=alt)
                 self.assertAlmostEqual(obs[0], exp)
@@ -186,7 +188,7 @@ class MantelTests(MantelTestData):
         for method in self.methods:
             obs = mantel(self.minx, self.minx, method=method,
                          alternative='less')
-            self.assertEqual(obs, (1, 1, 3))
+            npt.assert_almost_equal(obs, (1, 1, 3))
 
         np.random.seed(0)
 
@@ -239,23 +241,20 @@ class MantelTests(MantelTestData):
         self.assertEqual(obs[2], 24)
 
     def test_no_variation_pearson(self):
-        # Output doesn't match vegan::mantel with method='pearson'. Consider
-        # revising output and this test depending on outcome of
-        # https://github.com/scipy/scipy/issues/3728
         for alt in self.alternatives:
             # test one or both inputs having no variation in their
             # distances
             obs = mantel(self.miny, self.no_variation, method='pearson',
                          alternative=alt)
-            npt.assert_equal(obs, (0.0, 1.0, 3))
+            npt.assert_equal(obs, (np.nan, np.nan, 3))
 
             obs = mantel(self.no_variation, self.miny, method='pearson',
                          alternative=alt)
-            npt.assert_equal(obs, (0.0, 1.0, 3))
+            npt.assert_equal(obs, (np.nan, np.nan, 3))
 
             obs = mantel(self.no_variation, self.no_variation,
                          method='pearson', alternative=alt)
-            npt.assert_equal(obs, (1.0, 1.0, 3))
+            npt.assert_equal(obs, (np.nan, np.nan, 3))
 
     def test_no_variation_spearman(self):
         exp = (np.nan, np.nan, 3)
