@@ -16,7 +16,7 @@ Functions
 ^^^^^^^^^
 
 .. autosummary::
-   :toctree: generated/
+   :toctree:
 
    hommola_cospeciation
 
@@ -30,10 +30,6 @@ Functions
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from skbio.util import TestRunner
-
 from ._hommola import hommola_cospeciation
 
 __all__ = ['hommola_cospeciation']
-
-test = TestRunner(__file__).test
