@@ -18,7 +18,8 @@ import copy
 from skbio.util import assert_data_frame_almost_equal
 from skbio.stats.composition import (closure, multiplicative_replacement,
                                      perturb, perturb_inv, power, inner,
-                                     clr, clr_inv, ilr, ilr_inv,
+                                     clr, clr_inv, ilr, ilr_inv, alr, alr_inv,
+                                     sbp_basis, _gram_schmidt_basis,
                                      centralize, _holm_bonferroni, ancom)
 
 
@@ -393,6 +394,104 @@ class CompositionTests(TestCase):
         with self.assertRaises(ValueError):
             ilr_inv(table, basis=basis)
 
+    def test_alr(self):
+        # 2d-composition
+        comp1 = closure(self.cdata1)
+        alr2d_byhand = np.array([np.log(comp1[:, 0]/comp1[:, 1]),
+                                 np.log(comp1[:, 2]/comp1[:, 1])]).T
+        alr2d_method = alr(comp1, denominator_idx=1)
+        npt.assert_allclose(alr2d_byhand, alr2d_method)
+
+        # 1d-composition
+        comp2 = closure(self.cdata2)
+        alr1d_byhand = np.array([np.log(comp2[0]/comp2[1]),
+                                 np.log(comp2[2]/comp2[1])]).T
+        alr1d_method = alr(comp2, denominator_idx=1)
+        npt.assert_allclose(alr1d_byhand, alr1d_method)
+
+        with self.assertRaises(ValueError):
+            alr(self.bad1)
+        with self.assertRaises(ValueError):
+            alr(self.bad2)
+
+        # make sure that inplace modification is not occurring
+        alr(self.cdata2)
+        npt.assert_allclose(self.cdata2, np.array([2, 2, 6]))
+
+    def test_alr_inv(self):
+        # 2d-composition
+        comp1 = closure(self.cdata1)
+        alr2d_byhand = np.array([np.log(comp1[:, 0]/comp1[:, 1]),
+                                 np.log(comp1[:, 2]/comp1[:, 1])]).T
+        alr2d_method = alr(comp1, denominator_idx=1)
+        B = 1/(1 + np.exp(alr2d_byhand[:, 0]) + np.exp(alr2d_byhand[:, 1]))
+        A = B * np.exp(alr2d_byhand[:, 0])
+        C = B * np.exp(alr2d_byhand[:, 1])
+        alrinv2d_byhand = np.column_stack((A, B, C))
+        alrinv2d_method = alr_inv(alr2d_method, denominator_idx=1)
+        npt.assert_allclose(alrinv2d_byhand, alrinv2d_method)
+
+        # 1d-composition
+        comp2 = closure(self.cdata2)
+        alr1d_byhand = np.array([np.log(comp2[0]/comp2[1]),
+                                 np.log(comp2[2]/comp2[1])]).T
+        alr1d_method = alr(comp2, denominator_idx=1)
+        B = 1/(1 + np.exp(alr1d_byhand[0]) + np.exp(alr1d_byhand[1]))
+        A = B * np.exp(alr1d_byhand[0])
+        C = B * np.exp(alr1d_byhand[1])
+        alrinv1d_byhand = np.column_stack((A, B, C))[0, :]
+        alrinv1d_method = alr_inv(alr1d_method, denominator_idx=1)
+        npt.assert_allclose(alrinv1d_byhand, alrinv1d_method)
+
+        # make sure that inplace modification is not occurring
+        alr_inv(self.rdata1)
+        npt.assert_allclose(self.rdata1,
+                            np.array([[0.70710678, -0.70710678, 0., 0.],
+                                      [0.40824829, 0.40824829,
+                                       -0.81649658, 0.],
+                                      [0.28867513, 0.28867513,
+                                       0.28867513, -0.8660254]]))
+
+        with self.assertRaises(ValueError):
+            alr_inv(self.bad2)
+
+    def test_sbp_basis_gram_schmidt(self):
+        gsbasis = clr_inv(_gram_schmidt_basis(5))
+        sbp = np.array([[1, -1, 0, 0, 0],
+                        [1, 1, -1, 0, 0],
+                        [1, 1, 1, -1, 0],
+                        [1, 1, 1, 1, -1]])
+        sbpbasis = sbp_basis(sbp)
+        npt.assert_allclose(gsbasis, sbpbasis)
+
+    def test_sbp_basis_elementwise(self):
+        sbp = np.array([[1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, -1],
+                        [1, 1, 1, 1, 1, 1, 1, -1, -1, -1, -1, 0],
+                        [1, 1, 1, 1, 1, 1, -1, 0, 0, 0, 0, 0],
+                        [1, 1, -1, -1, -1, 1, 0, 0, 0, 0, 0, 0],
+                        [1, -1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0],
+                        [1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0],
+                        [0, 0, 1, -1, -1, 0, 0, 0, 0, 0, 0, 0],
+                        [0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0],
+                        [0, 0, 0, 0, 0, 0, 0, 1, -1, -1, 1, 0],
+                        [0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0],
+                        [0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0]])
+        sbpbasis = sbp_basis(sbp)
+        # by hand, element-wise
+        r = np.apply_along_axis(func1d=lambda x: np.sum(x > 0),
+                                axis=1, arr=sbp)
+        s = np.apply_along_axis(func1d=lambda x: np.sum(x < 0),
+                                axis=1, arr=sbp)
+        psi = np.zeros(sbp.shape)
+        for i in range(0, sbp.shape[0]):
+            for j in range(0, sbp.shape[1]):
+                if sbp[i, j] == 1:
+                    psi[i, j] = np.sqrt(s[i]/(r[i]*(r[i]+s[i])))
+                elif sbp[i, j] == -1:
+                    psi[i, j] = -np.sqrt(r[i]/(s[i]*(r[i]+s[i])))
+        basis_byhand = clr_inv(psi)
+        npt.assert_allclose(basis_byhand, sbpbasis)
+
 
 class AncomTests(TestCase):
     def setUp(self):
