@@ -181,8 +181,6 @@ pairwise tip-to-tip distances between trees:
 # The full license is in the file COPYING.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from skbio.util import TestRunner
-
 from ._tree import TreeNode
 from ._nj import nj
 from ._majority_rule import majority_rule
@@ -191,5 +189,3 @@ from ._exception import (TreeError, NoLengthError, DuplicateNodeError,
 
 __all__ = ['TreeNode', 'nj', 'majority_rule', 'TreeError', 'NoLengthError',
            'DuplicateNodeError', 'MissingNodeError', 'NoParentError']
-
-test = TestRunner(__file__).test
