@@ -17,7 +17,6 @@ Common functionality to support testing in skbio.
    :toctree: generated/
 
    get_data_path
-   TestRunner
    assert_ordination_results_equal
    assert_data_frame_almost_equal
 
@@ -55,14 +54,12 @@ Warnings
 
 from ._warning import EfficiencyWarning, RepresentationWarning, SkbioWarning
 from ._misc import cardinal_to_ordinal, find_duplicates, safe_md5
-from ._testing import (get_data_path, TestRunner,
+from ._testing import (get_data_path,
                        assert_ordination_results_equal,
-                       assert_data_frame_almost_equal)
+                       assert_data_frame_almost_equal, pytestrunner)
 from ._decorator import classproperty
 
 __all__ = ['SkbioWarning', 'EfficiencyWarning', 'RepresentationWarning',
            'cardinal_to_ordinal', 'find_duplicates', 'safe_md5',
-           'get_data_path', 'TestRunner', 'assert_ordination_results_equal',
-           'assert_data_frame_almost_equal', 'classproperty']
-
-test = TestRunner(__file__).test
+           'get_data_path', 'assert_ordination_results_equal',
+           'assert_data_frame_almost_equal', 'classproperty', 'pytestrunner']
